scxpand.linear.linear\_trainer
==============================

.. automodule:: scxpand.linear.linear_trainer

   
   .. rubric:: Functions

   .. autosummary::
   
      run_linear_training
   
   .. rubric:: Classes

   .. autosummary::
   
      LinearBatchPredictor
      LinearTrainLogger
      LinearTrainer
      TrainingSession
   